/* --COPYRIGHT--,BSD
 * Copyright (c) 2017, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/
//#############################################################################
//
//! \file   Applications.c
//
//  Group:          MSP
//  Target Devices: MSP430FR2512
//
//  (C) Copyright 2018, Texas Instruments, Inc.
//#############################################################################
// TI Release: 1.81.00.07
// Release Date: 6/9/2020

#include "msp430.h"
#include <captivate.h>           // CapTIvate Touch Software Library
#include "CAPT_UserConfig.h"     // CapTIvate Auto-Generated User Configuration
#include "Applications.h"
#include "I2CSlave.h"

//#ifdef __TI_COMPILER_VERSION__

#pragma PERSISTENT(CONV_COUNT00)
unsigned int CONV_COUNT00 = 0;

#pragma PERSISTENT(CONV_COUNT01)
unsigned int CONV_COUNT01 = 0;

#pragma PERSISTENT(CONV_COUNT02)
unsigned int CONV_COUNT02 = 0;

#pragma PERSISTENT(CONV_COUNT03)
unsigned int CONV_COUNT03 = 0;

#pragma PERSISTENT(MUTE_DET_STATE)
unsigned int MUTE_DET_STATE = 0;

#pragma PERSISTENT(CODE_VERSION)
unsigned int CODE_VERSION = 0;

unsigned int *FRAM_write_ptr = 0;
/*************************************************************************
* @brief  Called when BTN01 status has changed
* @param
*   1.tSensor *pButton
* @retval
*   1.None
**************************************************************************/
void BTN01EventHandler(tSensor *pButton)
{
    if((pButton->bSensorTouch == 0) && (pButton->bSensorPrevTouch == 1))
    {
        if (MUTE_DET_STATE == 0)
        {
            SYSCFG0 = FRWPPW;                   // Program FRAM write enable
            MUTE_DET_STATE = 1;
            SYSCFG0 = FRWPPW | PFWP | DFWP;            // Program FRAM write protected (not writable)

            MUTE_ON;
        }
        else
        {
            SYSCFG0 = FRWPPW;                   // Program FRAM write enable
            MUTE_DET_STATE = 0;
            SYSCFG0 = FRWPPW | PFWP | DFWP;            // Program FRAM write protected (not writable)

            MUTE_OFF;
        }
    }
}

/*************************************************************************
* @brief  Update parameters if the master has changed it
* @param
*   1.None
* @retval
*   1.None
**************************************************************************/
void APP_CheckForParamenterUpdate()
{
    I2CSlave_setRequestFlag();                 //set request
    SYSCFG0 = FRWPPW;                   // Info FRAM write enable

    if(CONV_COUNT00 != BTN00.ui16ConversionCount)
    {
        CONV_COUNT00 = BTN00.ui16ConversionCount;
    }

    if(CONV_COUNT01 != BTN01.ui16ConversionCount)
    {
        CONV_COUNT01 = BTN01.ui16ConversionCount;
    }

    if(CONV_COUNT02 != BTN02.ui16ConversionCount)
    {
        CONV_COUNT02 = BTN02.ui16ConversionCount;
    }

    if(CONV_COUNT03 != BTN03.ui16ConversionCount)
    {
        CONV_COUNT03 = BTN03.ui16ConversionCount;
    }

    SYSCFG0 = FRWPPW | PFWP | DFWP;            // Program FRAM write protected (not writable)
}

/*************************************************************************
* @brief  init customized function
* @param
*   1.None
* @retval
*   1.None
**************************************************************************/
void Panel_Init()
{
    // Check default Conversion count and gain
    if(CONV_COUNT00 == 0)
    {   // Save Parameters to FRAM
        SYSCFG0 = FRWPPW;                   // Program FRAM write enable

        CONV_COUNT00 = BTN00.ui16ConversionCount;
        CONV_COUNT01 = BTN01.ui16ConversionCount;
        CONV_COUNT02 = BTN02.ui16ConversionCount;
        CONV_COUNT03 = BTN03.ui16ConversionCount;
        SYSCFG0 = FRWPPW | PFWP | DFWP;            // Program FRAM write protected (not writable)
    }
    else // Load Parameters from FRAM
    {
        BTN00.ui16ConversionCount = CONV_COUNT00;
        BTN01.ui16ConversionCount = CONV_COUNT01;
        BTN02.ui16ConversionCount = CONV_COUNT02;
        BTN03.ui16ConversionCount = CONV_COUNT03;
    }

    BTN01.pvCallback = &BTN01EventHandler;

    // Configure P1.0 as output
    P1DIR |= BIT0;
    if (MUTE_DET_STATE == 0)
        MUTE_OFF;
    else
        MUTE_ON;

    // Configure INQ PIN and set it as output low
    P2DIR |= BIT2;
    P2OUT &= ~BIT2;

    // Configure P1.2 and P1.3 as I2C
    P1OUT  = (BIT0);
    P1SEL0 = (GPIO_PIN2 | GPIO_PIN3);
    P1SEL1 = (0);
}

/*************************************************************************
* @brief  update buffer when master need the mute state
* @param
*   1.uint8_t *pBuffer
* @retval
*   1.None
**************************************************************************/
void Cus_getGeneralPurposePacket(uint8_t *pBuffer)
{
    switch(pBuffer[4])
    {
    case(MUTE_CMD):
        if( pBuffer[5] == 1)
        {
            pBuffer[5] = 0;
            pBuffer[6] = MUTE_DET_STATE;
        }
        break;
    case(VERSION_CMD):
        if( pBuffer[5] == 1)
        {
            pBuffer[5] = 0;
            pBuffer[6] = CODE_VERSION;
        }
        break;
    case(BOOTLOADER):
        if( pBuffer[5] == 1)
        {
            //change 0xFFFE to 0xFFFF
            SYSCFG0 = FRWPPW;
            FRAM_write_ptr = (unsigned int *)0xFFFE;
            *FRAM_write_ptr = 0xFFFF;
            SYSCFG0 = FRWPPW | PFWP | DFWP;
            pBuffer[5] = 0;
            pBuffer[6] = 0x01;
        }
        break;
    default:
        break;
    }
}


