/* --COPYRIGHT--,BSD
 * Copyright (c) 2017, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/
//*****************************************************************************
// Development main.c for MSP430FR2522 and MSP430FR2512 CapTIvate devices.
//
// This starter application initializes the CapTIvate touch library
// for the touch panel specified by CAPT_UserConfig.c/.h via a call to
// CAPT_appStart(), which initializes and calibrates all sensors in the
// application, and starts the CapTIvate interval timer.
//
// Then, the capacitive touch interface is driven by calling the CapTIvate
// application handler, CAPT_appHandler().  The application handler manages
// whether the user interface (UI) is running in full active scan mode, or
// in a low-power wake-on-proximity mode.
//
// \version 1.83.00.05
// Released on May 15, 2020
//
//*****************************************************************************

#include <msp430.h>                      // Generic MSP430 Device Include
#include "driverlib.h"                   // MSPWare Driver Library
#include "captivate.h"                   // CapTIvate Touch Software Library
#include "CAPT_App.h"                    // CapTIvate Application Code
#include "CAPT_BSP.h"                    // CapTIvate EVM Board Support Package
#include "Applications.h"

char NoiseState = 0;
uint16_t NoiseLevel = 0;
uint16_t NoiseCount = 0;

void EMCLevel_Change(void)
{
    if(NoiseState == 2)
    {
        g_EMCConfig.selfModeOversamplingStyle = e4xOversampling;
        MAP_CAPT_loadEMCConfig(&g_EMCConfig);
        BTN00.ui8CntBeta = 2;
    }
    else if(NoiseState == 1)
    {
        g_EMCConfig.selfModeOversamplingStyle = e2xOversampling;
        MAP_CAPT_loadEMCConfig(&g_EMCConfig);
        BTN00.ui8CntBeta = 2;
    }
    else
    {
        g_EMCConfig.selfModeOversamplingStyle = eNoOversampling;
        MAP_CAPT_loadEMCConfig(&g_EMCConfig);
        BTN00.ui8CntBeta = 1;

    }
}

void EMCLevel_Evaluation(void)
{
    NoiseLevel = CAPT_getGlobalFilteredNoiseLevel();
    if(NoiseCount > 300)
    {
        EMCLevel_Change();
        NoiseState= 0;
        NoiseCount = 0;
    }
    else
    {
        NoiseCount++;
        if(( NoiseLevel>20)&&(NoiseState < 2))
        {
            NoiseState = 2;
        }
        else if(( NoiseLevel>10)&&(NoiseState <1))
        {
            NoiseState = 1;
        }
    }
}

void main(void)
{
    //
    // Initialize the MCU
    // BSP_configureMCU() sets up the device IO and clocking
    // The global interrupt enable is set to allow peripherals
    // to wake the MCU.
    //
    WDTCTL = WDTPW | WDTHOLD;
    BSP_configureMCU();
    Panel_Init();
    __bis_SR_register(GIE);

    //
    // Start the CapTIvate application
    //
    CAPT_appStart();

    //
    // Background Loop
    //
    while(1)
    {
        //
        // Run the captivate application handler.
        //

        CAPT_appHandler();

        //
        // This is a great place to add in any
        // background application code.
        //
        EMCLevel_Evaluation();
        APP_CheckForParamenterUpdate();

        //
        // End of background loop iteration
        // Go to sleep if there is nothing left to do
        //
        CAPT_appSleep();

    } // End background loop
} // End main()
